@@ -152,9 +152,14 @@ action_quit (GSimpleAction *action,
 
 	/* nautilus_window_close() doesn't do anything for desktop windows */
 	windows = nautilus_application_get_windows (application);
+        /* make a copy, since the original list will be modified when destroying
+         * a window, making this list invalid */
+        windows = g_list_copy (windows);
 	for (l = windows; l != NULL; l = l->next) {
 		nautilus_window_close (l->data);
 	}
+
+        g_list_free (windows);
 }
 
 static void
@@ -177,6 +182,17 @@ action_show_hide_sidebar (GSimpleAction *action,
 	g_simple_action_set_state (action, state);
 }
 
+static void
+action_show_help_overlay (GSimpleAction *action,
+                          GVariant      *state,
+                          gpointer       user_data)
+{
+        GtkApplication *application = user_data;
+        GtkWindow *window = gtk_application_get_active_window (application);
+
+        g_action_group_activate_action (G_ACTION_GROUP (window), "show-help-overlay", NULL);
+}
+
 static GActionEntry app_entries[] = {
 	{ "new-window", action_new_window, NULL, NULL, NULL },
 	{ "bookmarks", action_bookmarks, NULL, NULL, NULL },
@@ -188,6 +204,7 @@ static GActionEntry app_entries[] = {
 	{ "kill", action_kill, NULL, NULL, NULL },
 	{ "open-desktop", action_open_desktop, NULL, NULL, NULL },
 	{ "close-desktop", action_close_desktop, NULL, NULL, NULL },
+	{ "show-help-overlay", action_show_help_overlay, NULL, NULL, NULL },
 };
 
 void
@@ -202,19 +219,6 @@ nautilus_init_application_actions (NautilusApplication *app)
 					 app_entries, G_N_ELEMENTS (app_entries),
 					 app);
 
-	builder = gtk_builder_new ();
-	gtk_builder_add_from_resource (builder, "/org/gnome/nautilus/nautilus-app-menu.ui", &error);
-
-	if (error == NULL) {
-		gtk_application_set_app_menu (GTK_APPLICATION (app),
-					      G_MENU_MODEL (gtk_builder_get_object (builder, "app-menu")));
-	} else {
-		g_critical ("Unable to add the application menu: %s\n", error->message);
-		g_error_free (error);
-	}
-
-	g_object_unref (builder);
-
 	debug_no_app_menu = g_getenv ("NAUTILUS_DEBUG_NO_APP_MENU");
 	if (debug_no_app_menu) {
 		DEBUG ("Disabling app menu GtkSetting as requested...");
