@@ -513,6 +513,8 @@ nautilus_application_open_location_full (NautilusApplication     *application,
 	} else {
 		target_window = nautilus_application_create_window (application,
                                                                     gtk_window_get_screen (GTK_WINDOW (active_window)));
+                /* Whatever the caller says, the slot won't be the same */
+                target_slot = NULL;
 	}
 
         g_assert (target_window != NULL);
@@ -983,7 +985,7 @@ theme_changed (GtkSettings *settings)
 			GFile *file;
 
 			provider = gtk_css_provider_new ();
-			file = g_file_new_for_uri ("resource:///org/gnome/nautilus/Adwaita.css");
+			file = g_file_new_for_uri ("resource:///org/gnome/nautilus/css/Adwaita.css");
 			gtk_css_provider_load_from_file (provider, file, NULL);
 			g_object_unref (file);
 		}
@@ -1023,6 +1025,8 @@ nautilus_application_startup (GApplication *app)
 
 	nautilus_profile_start (NULL);
 
+	g_application_set_resource_base_path (app, "/org/gnome/nautilus");
+
 	/* chain up to the GTK+ implementation early, so gtk_init()
 	 * is called for us.
 	 */
