@@ -16,8 +16,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   see <http://www.gnu.org/licenses/>.
 
    Authors: Mike Engber <engber@eazel.com>
 */
@@ -51,6 +50,6 @@ typedef struct {
 
 /* GObject support */
 GType   nautilus_desktop_canvas_view_get_type (void);
-NautilusView * nautilus_desktop_canvas_view_new (NautilusWindowSlot *slot);
+NautilusFilesView * nautilus_desktop_canvas_view_new (NautilusWindowSlot *slot);
 
 #endif /* NAUTILUS_DESKTOP_CANVAS_VIEW_H */
