@@ -250,31 +250,6 @@ nautilus_mime_actions_get_required_file_attributes (void)
 		NAUTILUS_FILE_ATTRIBUTE_LINK_INFO;
 }
 
-static gboolean
-file_has_local_path (NautilusFile *file)
-{
-	GFile *location;
-	char *path;
-	gboolean res;
-
-	
-	/* Don't only check _is_native, because we want to support
-	   using the fuse path */
-	location = nautilus_file_get_location (file);
-	if (g_file_is_native (location)) {
-		res = TRUE;
-	} else {
-		path = g_file_get_path (location);
-		
-		res = path != NULL;
-		
-		g_free (path);
-	}
-	g_object_unref (location);
-	
-	return res;
-}
-
 GAppInfo *
 nautilus_mime_get_default_application_for_file (NautilusFile *file)
 {
@@ -287,7 +262,7 @@ nautilus_mime_get_default_application_for_file (NautilusFile *file)
 	}
 
 	mime_type = nautilus_file_get_mime_type (file);
-	app = g_app_info_get_default_for_type (mime_type, !file_has_local_path (file));
+	app = g_app_info_get_default_for_type (mime_type, !nautilus_file_is_local (file));
 	g_free (mime_type);
 
 	if (app == NULL) {
@@ -1063,15 +1038,18 @@ search_for_application_dbus_call_notify_cb (GDBusProxy   *proxy,
 	if (variant == NULL) {
 		if (!g_dbus_error_is_remote_error (error) ||
 		    g_strcmp0 (g_dbus_error_get_remote_error (error), "org.freedesktop.PackageKit.Modify.Failed") == 0) {
-			    char *message;
+			char *message;
 
-			    message = g_strdup_printf ("%s\n%s",
-						       _("There was an internal error trying to search for applications:"),
-						       error->message);
-			    eel_show_error_dialog (_("Unable to search for application"), message,
-			                           parameters_install->parent_window);
-			    g_free (message);
-		    }
+			message = g_strdup_printf ("%s\n%s",
+						   _("There was an internal error trying to search for applications:"),
+						   error->message);
+			eel_show_error_dialog (_("Unable to search for application"), message,
+					       parameters_install->parent_window);
+			g_free (message);
+		} else {
+			g_warning ("Error while trying to search for applications: %s",
+				   error->message);
+		}
 
 		g_error_free (error);
 		activate_parameters_install_free (parameters_install);
@@ -1157,27 +1135,28 @@ pk_proxy_appeared_cb (GObject *source,
 		      gpointer user_data)
 {
         ActivateParametersInstall *parameters_install = user_data;
-	char *mime_type;
+	char *mime_type, *name_owner;
 	char *error_message;
 	GtkWidget *dialog;
         GDBusProxy *proxy;
 	GError *error = NULL;
 
 	proxy = g_dbus_proxy_new_for_bus_finish (res, &error);
+	name_owner = g_dbus_proxy_get_name_owner (proxy);
 
-	if (error != NULL) {
+	if (error != NULL || name_owner == NULL) {
 		g_warning ("Couldn't call Modify on the PackageKit interface: %s",
-			   error->message);
-		g_error_free (error);
+			   error != NULL ? error->message : "no owner for PackageKit");
+		g_clear_error (&error);
 
 		/* show an unhelpful dialog */
 		show_unhandled_type_error (parameters_install);
-		/* The callback wasn't started, so we have to free the parameters */
-		activate_parameters_install_free (parameters_install);
 
 		return;
 	}
 
+	g_free (name_owner);
+
 	mime_type = nautilus_file_get_mime_type (parameters_install->file);
 	error_message = get_application_no_mime_type_handler_message (parameters_install->file,
 	                                                              parameters_install->uri);
@@ -1549,8 +1528,12 @@ activate_files (ActivateParameters *parameters)
 
 			uri = nautilus_file_get_activation_uri (file);
 			f = g_file_new_for_uri (uri);
+                        /* FIXME: we need to pass the parent_window, but we only use it for the current active window,
+                         * which nautilus-application should take care of. However is not working and creating regressions
+                         * in some cases. Until we figure out what's going on, continue to use the parameters->slot
+                         * to make splicit the window we want to use for activating the files */
                         nautilus_application_open_location_full (NAUTILUS_APPLICATION (g_application_get_default ()),
-                                                                 f, flags, NULL, NULL, NULL);
+                                                                 f, flags, NULL, NULL, parameters->slot);
 			g_object_unref (f);
 			g_free (uri);
 		}
