@@ -249,13 +249,14 @@ nautilus_window_slot_content_view_matches (NautilusWindowSlot *slot,
 }
 
 static void
-update_search_visible (NautilusWindowSlot *slot)
+check_search_visible (NautilusWindowSlot *slot)
 {
         NautilusQuery *query;
         NautilusView *view;
         gchar *text;
         GAction *action;
 
+        query = nautilus_query_editor_get_query (slot->details->query_editor);
         action =  g_action_map_lookup_action (G_ACTION_MAP (slot->details->slot_action_group),
                                               "search-visible");
         /* Don't allow search on desktop */
@@ -264,15 +265,10 @@ update_search_visible (NautilusWindowSlot *slot)
 
         view = nautilus_window_slot_get_current_view (slot);
         /* If we changed location just to another search location, for example,
-         * when changing the query, just keep the search visible.
-         * Make sure the search is visible though, since we could be returning
-         * from a previous search location when using the history */
-        if (nautilus_view_is_searching (view)) {
-                nautilus_window_slot_set_search_visible (slot, TRUE);
+         * when changing the query, just keep the search visible */
+        if (nautilus_view_is_searching (view))
                 return;
-         }
 
-        query = nautilus_query_editor_get_query (slot->details->query_editor);
         if (query) {
                 text = nautilus_query_get_text (query);
                 /* If the view is not searching, but search is visible, and the
@@ -299,10 +295,10 @@ nautilus_window_slot_sync_actions (NautilusWindowSlot *slot)
 		return;
 	}
 
-        /* Check if we need to close the search or show search after changing the location.
+        /* Check if we need to close the search or not after changing the location.
          * Needs to be done after the change has been done, if not, a loop happens,
          * because setting the search enabled or not actually opens a location */
-        update_search_visible (slot);
+        check_search_visible (slot);
 
         /* Files view mode */
         action =  g_action_map_lookup_action (G_ACTION_MAP (slot->details->slot_action_group), "files-view-mode");
@@ -750,13 +746,6 @@ nautilus_window_slot_init (NautilusWindowSlot *slot)
  */
 #include "nautilus-desktop-window.h"
 
-/* This number controls a maximum character count for a URL that is
- * displayed as part of a dialog. It's fairly arbitrary -- big enough
- * to allow most "normal" URIs to display in full, but small enough to
- * prevent the dialog from getting insanely wide.
- */
-#define MAX_URI_IN_DIALOG_LENGTH 60
-
 static void begin_location_change                     (NautilusWindowSlot         *slot,
                                                        GFile                      *location,
                                                        GFile                      *previous_location,
@@ -766,6 +755,7 @@ static void begin_location_change                     (NautilusWindowSlot
                                                        const char                 *scroll_pos);
 static void free_location_change                      (NautilusWindowSlot         *slot);
 static void end_location_change                       (NautilusWindowSlot         *slot);
+static void cancel_location_change                    (NautilusWindowSlot         *slot);
 static void got_file_info_for_view_selection_callback (NautilusFile               *file,
 						       gpointer                    callback_data);
 static gboolean setup_view                            (NautilusWindowSlot *slot,
@@ -856,6 +846,8 @@ check_force_reload (GFile                      *location,
 
 	if (type == NAUTILUS_LOCATION_CHANGE_RELOAD) {
 		force_reload = TRUE;
+	} else if (!nautilus_monitor_active ()) {
+		force_reload = TRUE;
 	} else {
 		force_reload = !nautilus_directory_is_local (directory);
 	}
@@ -923,14 +915,17 @@ begin_location_change (NautilusWindowSlot         *slot,
         nautilus_window_slot_disconnect_content_view (slot);
         /* We are going to change the location, so make sure we stop any loading
          * or searching of the previous view, so we avoid to be slow */
-        nautilus_window_slot_stop_loading (slot);
+        if (slot->details->content_view && NAUTILUS_IS_FILES_VIEW (slot->details->content_view)) {
+                nautilus_files_view_stop_loading (NAUTILUS_FILES_VIEW (slot->details->content_view));
+        }
+
+	end_location_change (slot);
 
 	nautilus_window_slot_set_allow_stop (slot, TRUE);
 
         new_selection = check_select_old_location_containing_folder (new_selection, location, previous_location);
 
 	g_assert (slot->details->pending_location == NULL);
-	g_assert (slot->details->pending_selection == NULL);
 
 	slot->details->pending_location = g_object_ref (location);
 	slot->details->location_change_type = type;
@@ -1561,6 +1556,49 @@ free_location_change (NautilusWindowSlot *slot)
 			 got_file_info_for_view_selection_callback, slot);
                 slot->details->determine_view_file = NULL;
         }
+
+        if (slot->details->new_content_view != NULL) {
+		g_object_unref (slot->details->new_content_view);
+		slot->details->new_content_view = NULL;
+        }
+}
+
+static void
+cancel_location_change (NautilusWindowSlot *slot)
+{
+	GList *selection;
+	GFile *location;
+        NautilusDirectory *directory;
+
+	location = nautilus_window_slot_get_location (slot);
+
+	directory = nautilus_directory_get (slot->details->location);
+        /* Stops current loading or search if any, so we are not slow */
+        if (NAUTILUS_IS_FILES_VIEW (slot->details->content_view)) {
+                nautilus_files_view_stop_loading (NAUTILUS_FILES_VIEW (slot->details->content_view));
+        }
+        nautilus_directory_unref (directory);
+
+        if (slot->details->pending_location != NULL
+            && location != NULL
+            && slot->details->content_view != NULL
+            && NAUTILUS_IS_FILES_VIEW (slot->details->content_view)) {
+
+                /* No need to tell the new view - either it is the
+                 * same as the old view, in which case it will already
+                 * be told, or it is the very pending change we wish
+                 * to cancel.
+                 */
+		selection = nautilus_view_get_selection (slot->details->content_view);
+                load_new_location (slot,
+				   location,
+				   selection,
+				   TRUE,
+				   FALSE);
+		nautilus_file_list_free (selection);
+        }
+
+        end_location_change (slot);
 }
 
 void
@@ -1585,7 +1623,7 @@ nautilus_window_slot_set_content_view (NautilusWindowSlot *slot,
         selection = nautilus_view_get_selection (slot->details->content_view);
         view = nautilus_files_view_new (id, slot);
 
-        nautilus_window_slot_stop_loading (slot);
+        end_location_change (slot);
 
         nautilus_window_slot_set_allow_stop (slot, TRUE);
 
@@ -2264,9 +2302,6 @@ nautilus_window_slot_dispose (GObject *object)
 	}
 
 	nautilus_window_slot_set_viewed_file (slot, NULL);
-	/* TODO? why do we unref here? the file is NULL.
-	 * It was already here before the slot move, though */
-	nautilus_file_unref (slot->details->viewed_file);
 
         g_clear_object (&slot->details->location);
 
@@ -2499,44 +2534,7 @@ nautilus_window_slot_set_allow_stop (NautilusWindowSlot *slot,
 void
 nautilus_window_slot_stop_loading (NautilusWindowSlot *slot)
 {
-        GList *selection;
-        GFile *location;
-        NautilusDirectory *directory;
-
-        location = nautilus_window_slot_get_location (slot);
-
-        directory = nautilus_directory_get (slot->details->location);
-
-        if (NAUTILUS_IS_FILES_VIEW (slot->details->content_view)) {
-                nautilus_files_view_stop_loading (NAUTILUS_FILES_VIEW (slot->details->content_view));
-        }
-
-        nautilus_directory_unref (directory);
-
-        if (slot->details->pending_location != NULL &&
-            location != NULL &&
-            slot->details->content_view != NULL &&
-            NAUTILUS_IS_FILES_VIEW (slot->details->content_view)) {
-                /* No need to tell the new view - either it is the
-                 * same as the old view, in which case it will already
-                 * be told, or it is the very pending change we wish
-                 * to cancel.
-                 */
-                selection = nautilus_view_get_selection (slot->details->content_view);
-                load_new_location (slot,
-                                   location,
-                                   selection,
-                                   TRUE,
-                                   FALSE);
-                nautilus_file_list_free (selection);
-        }
-
-        end_location_change (slot);
-
-        if (slot->details->new_content_view) {
-                g_object_unref (slot->details->new_content_view);
-                slot->details->new_content_view = NULL;
-        }
+        cancel_location_change (slot);
 }
 
 NautilusView*
